# OneBot Adapter for Kirara AI

本项目是 [Kirara-AI](https://github.com/lss233/Kirara-AI) 的一个插件，用于将OneBot协议的消息转换为Kirara-AI的消息格式。

## 安装

```bash
pip install chatgpt-mirai-qq-bot-onebot-adapter
```
## 使用

请浏览[使用文档](https://oa-docs.cloxl.com)。

## 开源协议

本项目基于 [Kirara-AI](https://github.com/lss233/kirara-ai) 开发，遵循其 [开源协议](https://github.com/lss233/kirara-ai/blob/master/LICENSE)

## 感谢

感谢 [kirara-ai](https://github.com/lss233/kirara-ai) 的作者 [lss233](https://github.com/lss233) 提供框架支持

感谢 [AIOCQHTTP](https://github.com/nonebot/aiocqhttp) 的作者 [nonebot](https://github.com/nonebot) 提供CQHTTP协议支持

